"""Top-level package for Tank Forecaster."""

__author__ = """Jim Vogel"""
__email__ = "james.vogel@capspire.com"
__version__ = "0.3.56"

# from tank_forecaster.tank_forecaster import decomp, events, forecaster, validation
